@@ -14,7 +14,7 @@ from globus_sdk.response import GlobusHTTPResponse, IterableResponse
 from globus_sdk.scopes import AuthScopes, Scope
 
 if t.TYPE_CHECKING:
-    from globus_sdk.experimental.globus_app import GlobusApp
+    from globus_sdk.globus_app import GlobusApp
 
 from .._common import get_jwk_data, pem_decode_jwk_data
 from ..data import DependentScopeSpec
@@ -838,7 +838,7 @@ class AuthClient(client.BaseClient):
         :param domain_constraints_exclude: A list of domains that cannot satisfy the
             policy
 
-        .. note:
+        .. note::
 
             ``project_id``, ``display_name``, and ``description`` are all required
             arguments, although they are not declared as required in the function
