@@ -26,6 +26,25 @@ def test_sha256string():
     assert utils.sha256_string(test_string) == expected_sha
 
 
+@pytest.mark.parametrize(
+    "platform_value, result",
+    (
+        # platform.node() can return '' when it doesn't know the hostname
+        # turn this into None
+        pytest.param("", None, id="empty-is-none"),
+        # macOS adds '.local' to the user's chosen machine name
+        pytest.param(
+            "VeryCoolMacbook.local", "VeryCoolMacbook", id="remove-local-suffix"
+        ),
+        # the "boring" case is when we do no extra work
+        pytest.param("linux-workstation", "linux-workstation", id="boring"),
+    ),
+)
+def test_get_nice_hostname(platform_value, result, monkeypatch):
+    monkeypatch.setattr("platform.node", lambda: platform_value)
+    assert utils.get_nice_hostname() == result
+
+
 @pytest.mark.parametrize(
     "a, b",
     [(a, b) for a in ["a", "a/"] for b in ["b", "/b"]]
@@ -98,27 +117,3 @@ def test_classproperty_prefers_instance():
 )
 def test_safe_strseq_iter(value, expected_result):
     assert list(utils.safe_strseq_iter(value)) == expected_result
-
-
-@pytest.mark.parametrize("value", (uuid.UUID(int=0), str(uuid.UUID(int=1))))
-def test_check_uuid_ok(value):
-    # no error and returns True
-    assert utils.check_uuid(value, name="foo")
-
-
-@pytest.mark.parametrize("value", (str(uuid.UUID(int=0))[:-1], ""))
-def test_check_uuid_fails_value(value):
-    with pytest.raises(ValueError, match="'foo' must be a valid UUID") as excinfo:
-        utils.check_uuid(value, name="foo")
-
-    err = excinfo.value
-    assert f"value='{value}'" in str(err)
-
-
-@pytest.mark.parametrize("value", (object(), None, ["bar"]))
-def test_check_uuid_fails_type(value):
-    with pytest.raises(TypeError, match="'foo' must be a UUID or str") as excinfo:
-        utils.check_uuid(value, name="foo")
-
-    err = excinfo.value
-    assert f"value='{value}'" in str(err)
